<?php
/**
 * Custom template tags for this theme.
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package Billy-Montigny
 */

if ( ! function_exists( 'bm_the_custom_logo' ) ) :
	/**
	 * Displays the custom logo, not linked.
	 */
	function bm_the_custom_logo() {
		$custom_logo_id = get_theme_mod( 'custom_logo' );
		$logo = wp_get_attachment_image_src( $custom_logo_id , 'bm-header-logo' );
		if ( has_custom_logo() ) {
			echo '<img src="'. esc_url( $logo[0] ) .'" alt="'. get_bloginfo( 'name' ) . '">';
		} else {
			echo '<h1>'. get_bloginfo( 'name' ) .'</h1>';
		}
	}
endif;

if ( ! function_exists( 'bm_posted_on' ) ) :
	/**
	 * Prints HTML with meta information for the current post-date/time and author.
	 */
	function bm_posted_on() {
		$time_string = sprintf(
			'<time class="entry-date published" datetime="%1$s">%2$s</time>',
			esc_attr( get_the_date( 'c' ) ),
			esc_html( get_the_date() )
		);

		$posted_on = sprintf(
			/* translators: %s: post date. */
			esc_html_x( 'Posted on %s', 'post date', 'billy-montigny' ),
			$time_string
		);

		echo '<p class="posted-on">' . $posted_on . '</p>'; // WPCS: XSS OK.
	}
endif;

if ( ! function_exists( 'bm_the_content' ) ) :
	/**
	 * Displays the post content.
	 *
	 * @param bool $strip_teaser Optional. Strip teaser content before the more
	 *                           text. Default is false.
	 */
	function bm_the_content( $strip_teaser = false ) {
		the_content(
			sprintf(
				'<span aria-label="%1$s"><i class="icon-angle-right"></i> %2$s</span>',
				sprintf(
					/* translators: %s: name of current post */
					__( 'Continue reading %s' ),
					the_title_attribute( array( 'echo' => false ) )
				),
				__( 'Continue reading&hellip;', 'billy-montigny' )
			),
			$strip_teaser
		);
	}
endif;
