<?php
/**
 * Filters and custom functions to modify some widgets.
 *
 * @package Billy-Montigny
 */

/// Caldera Forms -------------------------------------------------------------

function bm_caldera_forms_get_field_types( $field_types ) {
	// use the Foundation class the button
	$field_types['button']['setup']['default']['class'] = 'button';

	return $field_types;
}

add_filter( 'caldera_forms_get_field_types', 'bm_caldera_forms_get_field_types' );

/// Event Organizer -----------------------------------------------------------

/**
 * Returns the format to use for date.
 *
 * @param bool $with_year Whether to display the year.
 *
 * @return string
 */
function bm_get_event_date_format( $with_year = true ) {
	// FIXME: stocker cette valeur quelque part.
	return $with_year ? 'l j F Y' : 'l j F';
}

/**
 * Returns the format to use for time.
 *
 * @param bool $with_separator Whether to prepend a separator.
 *
 * @return string
 */
function bm_get_event_time_format( $with_separator = false ) {
	$time_format = trim( get_option( 'time_format' ) );
	return $with_separator ? ' \à ' . $time_format : $time_format;
}

/**
 * A shortcut to the `eo_format_event_occurrence` call.
 *
 * @link http://codex.wp-event-organiser.com/function-eo_format_event_occurrence.html
 */
function bm_format_event_occurrence( $with_year = true ) {
	return eo_format_event_occurrence( false, false,
		bm_get_event_date_format( $with_year ),
		bm_get_event_time_format( true )
	);
}

/**
 * Filters the value returned by `eo_get_the_start()`.
 *
 * @param string|DateTime $formatted_start The DateTime object or formatted
 *                                         returned value (as determined by
 *                                         $format).
 * @param DateTime        $start           The start date as a DateTime object.
 * @param string          $format          The format the start date should be
 *                                         returned in.
 * @param int             $post_id         Post ID of the event.
 */
function bm_get_event_start( $formatted_start, $start, $format, $post_id ) {
	// quitte si aucun formattage n'est demandé
	if ( DATETIMEOBJ == $format ) {
		return $formatted_start;
	}

	$date_year = $start->format( 'Y' );
	$cur_year  = date( 'Y', current_time( 'timestamp' ) );

	// only show the year in the date if it's not in the current year
	$with_year = $date_year == $cur_year ? false : true;

	$date_format = bm_get_event_date_format( $with_year );
	$time_format = trim( get_option( 'time_format' ) );

	$new_format = $date_format;
	if ( ! eo_is_all_day( $post_id ) && false !== strpos( $format, 'H' ) ) {
		$new_format .= ' \à ' . $time_format;
	}

	return eo_format_datetime( $start, $new_format );
}

add_filter( 'eventorganiser_get_the_start', 'bm_get_event_start', 10, 4 );
