<?php
/**
 * Template part for displaying posts.
 *
 * @link https://codex.wordpress.org/Template_Hierarchy
 *
 * @package Billy-Montigny
 */

?>

<article id="post-<?php the_ID(); ?>" <?php post_class(); ?>>
	<header class="entry-header">
		<?php
		if ( is_single() ) {
			the_title( '<h2 class="entry-title">', '</h2>' );
		} else {
			the_title( '<h4 class="entry-title"><a href="' . esc_url( get_permalink() ) . '" rel="bookmark">', '</a></h4>' );
		} ?>
	</header>

	<div class="entry-summary">
		<?php
		// Check if the event has a thumbnail
		$has_thumbnail = ( '' != get_the_post_thumbnail() );

		if ( $has_thumbnail ) : ?>
			<div class="grid-x grid-margin-x">
				<div class="cell medium-shrink text-center">
					<a href="<?php the_post_thumbnail_url(); ?>" class="thumbnail medium-compact">
						<?php the_post_thumbnail( 'bm-featured-image-event' ); ?>
					</a>
				</div>

				<div class="cell auto">
		<?php endif; ?>

		<h4>Détails de l'événement</h4>

		<ul class="eo-event-meta no-bullet compact">
			<li class="eo-event-date">
				<span class="show-for-sr">Date :</span>
				<?php
				if ( eo_recurs() ) {
					// Event recurs - is there a next occurrence?
					$next = eo_get_next_occurrence( eo_get_event_datetime_format() );

					if ( $next ) {
						// If the event is occurring again in the future, display the date.
						printf( __( 'This event is running from %1$s until %2$s. It is next occurring on %3$s', 'eventorganiser' ), eo_get_schedule_start( 'j F Y' ), eo_get_schedule_last( 'j F Y' ), $next );
					} else {
						// Otherwise the event has finished (no more occurrences).
						printf( __( 'This event finished on %s', 'eventorganiser' ), eo_get_schedule_last( 'd F Y', '' ) );
					}
				} else {
					echo eo_format_event_occurrence();
				} ?>
			</li>

			<?php
			if ( eo_get_venue() ): ?>
				<li class="eo-event-venue">
					<span class="show-for-sr">Lieu :</span>
					<a href="<?php eo_venue_link(); ?>"> <?php eo_venue_name(); ?></a>
					<div class="eo-venue-address">
						<?php
						$address_details = eo_get_venue_address();
						echo join( ' – ', array(
							$address_details['address'],
							$address_details['city'],
						) );
						?>
					</div>
				</li>
			<?php endif; ?>

			<?php
			if ( get_the_terms( get_the_ID(), 'event-category' )
			     && ! is_wp_error( get_the_terms( get_the_ID(), 'event-category' ) ) ): ?>
				<div class="eo-event-category">
					<span class="show-for-sr">Catégories :</span>
					<?php echo get_the_term_list( get_the_ID(), 'event-category', '', ', ', '' ); ?>
				</div>
			<?php endif; ?>

			<?php
			if ( get_the_terms( get_the_ID(), 'event-tag' )
			     && ! is_wp_error( get_the_terms( get_the_ID(), 'event-tag' ) ) ): ?>
				<div class="eo-event-tags">
					<span class="show-for-sr">Étiquettes :</span>
					<?php echo get_the_term_list( get_the_ID(), 'event-tag', '', ', ', '' ); ?>
				</div>
			<?php endif; ?>

			<?php do_action( 'eventorganiser_additional_event_meta' ) ?>

		</ul>

		<?php if ( $has_thumbnail ) : ?>
				</div>
			</div>
		<?php endif; ?>
	</div>

	<?php if ( get_the_content() ): ?>
		<div class="entry-content">
			<?php the_content(); ?>
		</div>
	<?php endif; ?>
</article>
