<?php
/**
 * The template is used for displaying the Event List widget if the
 * placeholder option isn't used.
 *
 * Based on the default template from v3.1.7.
 *
 * @link http://docs.wp-event-organiser.com/theme-integration
 *
 * @package Billy-Montigny
 */
global $eo_event_loop, $eo_event_loop_args;

// The list ID / classes
$id      = ( $eo_event_loop_args['id'] ? 'id="' . $eo_event_loop_args['id'] . '"' : '' );
$classes = $eo_event_loop_args['class'];
?>

<?php if ( $eo_event_loop->have_posts() ) :  ?>

	<ul <?php echo $id; ?> class="<?php echo esc_attr( $classes ); ?> no-bullet">

		<?php while ( $eo_event_loop->have_posts() ) :  $eo_event_loop->the_post(); ?>

			<?php
				// Generate HTML classes for this event
				$eo_event_classes = eo_get_event_classes();

				// Get the start date as a DateTime object
				$start = eo_get_the_start( DATETIMEOBJ );

				// Check if the event has a thumbnail
				$has_thumbnail = ( '' != get_the_post_thumbnail() );
			?>

			<li class="<?php echo esc_attr( implode( ' ',$eo_event_classes ) ); ?>">

				<?php if ( $has_thumbnail ) : ?>
					<div class="grid-x">
						<div class="auto cell">
				<?php endif; ?>

				<div class="grid-x align-middle eo-event-header">
					<div class="shrink cell">
						<div class="eo-event-date-display">
							<span class="weekday">
								<?php echo eo_format_datetime( $start, 'D' ); ?>
							</span>
							<span class="date">
								<?php echo $start->format( 'd/m' ); ?>
							</span>
						</div>
					</div>

					<div class="auto cell eo-event-title">
						<a href="<?php echo eo_get_permalink(); ?>">
							<?php the_title(); ?>
						</a>
					</div>
				</div>

				<div class="eo-event-content">
					<div class="eo-event-time">
						à <?php echo $start->format( 'H\hi' ); ?>
					</div>
					<?php if ( eo_get_venue() ): ?>
					<div class="eo-event-venue">
						<?php echo eo_get_venue_name(); ?>
					</div>
					<?php endif; ?>
				</div>

				<?php if ( $has_thumbnail ) : ?>
						</div>

						<div class="shrink cell eo-event-thumbnail">
							<a href="<?php the_post_thumbnail_url(); ?>" class="thumbnail compact">
								<?php the_post_thumbnail( 'bm-featured-image-event' ); ?>
							</a>
						</div>
					</div>
				<?php endif; ?>

			</li>

		<?php endwhile; ?>

	</ul>

	<div class="eo-events-link">
		<a href="<?php echo esc_url( eo_get_event_archive_link( date( 'Y' ) ) ); ?>" rel="bookmark" class="button small compact">
			Voir tous les événements
		</a>
	</div>

<?php elseif ( ! empty( $eo_event_loop_args['no_events'] ) ) :  ?>

	<p class="eo-no-events" ><?php echo $eo_event_loop_args['no_events']; ?></p>

<?php endif;
